

import java.text.SimpleDateFormat;
import java.util.Date;
/**
 *
 * @author metcalfc
 */
public class Main {
	

    private static void usage () {
    	
        System.err.println (
        	"USAGE:\n" +
        	"    java TestbedProfiler [options] -m <mapFile>\n" +
        	"\n" +
       		"OPTIONS:\n" +
       		"    -o <outputFile>\n" +
       		"        The path to where the log/tracefile will be created (csv format).\n" +
       		"    -i <iterations>\n" +
       		"        The number of times a packet transmission should be repeated.\n" +
       		"    -p <powerLevel>\n" +
       		"        The power level at which to transmit\n" +
       		"    -c <channel>\n" +
       		"        The channel on which to broadcast\n" +
       		"    -s <payloadSize>\n" +
       		"        The size of the payload (in bytes) included with each packet.\n" +
       		"    -t <msgInterval>\n" +
       		"        The interval (in milliseconds) between packet transmissions.\n" +
       		"    -h, --help\n" +
       		"        Display this information\n"
        );
        
        
        System.exit(1);
        
    }

   
    private static String makeFileName() {

        SimpleDateFormat dateFormatter = new SimpleDateFormat("dd-MMM-yyyy_HH.mm.ss");

        StringBuffer file = new StringBuffer(
        	"profile-" + dateFormatter.format(new Date()) + ".csv"
        );

        return file.toString();
    }

    
    public static void main (String[] args) throws InterruptedException {
    	
        String map     = null;
        String path    = null;
        int iterations = 5;
        int power      = 1;
        int channel    = 15;
        int payload    = 50;
        int delay      = 50;
        int index      = 0;

        
        if (args.length >= 2) {
        	
            while (index < args.length) {

                String arg = args[index++];

                
                try {

                	if (arg.equals("-h") || arg.equals("--help")) {
                    
                		usage ();
                        
                	} else if (arg.equals("-m")) {
                        
                		map = args[index++];
                    
                	} else if (arg.equals("-o")) {
                        
                		path = args[index++];
                    
                	} else if (arg.equals("-i")) {
                    
                		iterations = Integer.parseInt(args[index++]);
                    
                	} else if (arg.equals("-p")) {
                    
                		power = Integer.parseInt(args[index++]);
                    
                	} else if (arg.equals("-c")) {
                    
                		channel = Integer.parseInt(args[index++]);
                    
                	} else if (arg.equals("-s")) {
                    
                		payload = Integer.parseInt(args[index++]);
                    
                	} else if (arg.equals("-t")) {
                        
                		delay = Integer.parseInt(args[index++]);
                    
					}
                	
                } catch (ArrayIndexOutOfBoundsException e) {
                	
                    usage ();
                
                }
            }

            
            if (map == null) {

            	usage ();

			} else if (iterations < 0) {
			
				System.err.println("The number of iterations cannot be negative.");

				System.exit(1);

            } else if (channel < 11 || channel > 26) {
            	
            	System.err.println("The radio channel must be between 11 and 26 (" + channel + " given).");
            	
            	System.exit(1);
            	
            } else if (power < 0 || power > 31) {
            	
            	System.err.println("Transmission power must be between 0 and 31 (" + power + " given).");
            	
            	System.exit(1);
            	
            } else if (payload < 10 || payload > 106) {
            	
            	System.err.println("Message payload must be between 10 and 106 bytes (" + payload + " given).");
            	
            	System.exit(1);
            	
            } else if (delay < 1 || delay > 65535) {
            	
            	System.err.println("Message interval must be between 1 and 65,535 ms (" + delay + " given).");
            	
            	System.exit(1);
            	
            }

            if (path == null) {
            	path = makeFileName();
            }
            
        } else {
        	
            usage ();
        
        }

        
        new TestbedProfiler(map, path, iterations, power, channel, payload, delay);

        
        System.exit(0);
        
    }
}
