import java.io.BufferedWriter;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;


public class ETXGraph {

	private final BufferedWriter out;
	private final Parser parser;
	
	
	
	public ETXGraph(String file, Parser parser) {
		
		this.out    = openOutfile(file);
		this.parser = parser; 
		
		
		
	}
	
	
	private BufferedWriter openOutfile(String file) {
		try {
			
			return new BufferedWriter(new FileWriter(file));
		
		} catch (IOException e) {}
		
		return null;
	}


	public void createGraph() {
		
		printStartOfScript();
		printConnections();
		printEndOfScript();
		
	}


	private void printStartOfScript() {
		try {
			out.write(
				"import matplotlib\n" +
				"matplotlib.use('Agg')\n" +
				"from pylab import *\n" +
				"from numpy import *\n" +
				"\n" +
				"# create the figure (no axes and white bg)\n" +
				"fig = figure(facecolor=None)\n" +
				"fig.gca().set_axis_off()\n" +
				"fig.set_size_inches(16,6)\n" +
				"ax = fig.add_subplot(111)\n" +
				"\n" +
				"# load the mote position map\n" +
				"motes = loadtxt('motemap36.txt', dtype=int)\n" +
				"x, y = motes[:,0], motes[:,1]\n" +
				"\n" +
				"# display the motes (scatterplot)\n" +
				"ax.scatter(x, y, c = 'r')\n" +
				"\n" +
				"\n" +
				"ax.axis([-0.2, 9, -0.2, 3.2])\n" +
				"\n" +
				"# add the colorbar\n" +
				"ax1  = fig.add_axes([0.92, 0.05, 0.04, 0.90])\n" +
				"cols = ['#008800', '#00FF00', '#FFFF00', '#FF9900', '#FF0000']\n" +
				"cmap = mpl.colors.LinearSegmentedColormap.from_list('MyCM', cols)\n" +
				"norm = mpl.colors.Normalize(vmin=1, vmax=3)\n" +
				"cb1  = mpl.colorbar.ColorbarBase(\n" +
				"	ax1, cmap=cmap, norm=norm,\n" +
				"	orientation='vertical',\n" +
				"	ticks=[1.0, 1.5, 2.0, 2.5, 3.0]\n" +
				")\n" +
				"\n"
			);
		} catch (IOException e) {
			e.printStackTrace();
		}		
	}
	
	
	private void printConnections() {

		ArrayList<Link> links = parser.getLinks();
		
		for (int i = 0, size = links.size(); i < size; i++) {
			
			Link link = links.get(i);
			
			if (link.getETX() > 0 && link.getETX() < 100) {
			
				Node n1  = link.getNode1();
				Node n2  = link.getNode2();
			
			

				try {
					out.write(
						"ax.add_line(Line2D(" +
						"[" + n1.getX() + "," + n2.getX() + "]," +
						"[" + n1.getY() + "," + n2.getY() + "]," +
						"color=cmap(norm(" + link.getETX() + " ))))" + "\n"
					);
					out.flush();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
		
	}
	
	
	private void printEndOfScript() {
		// TODO Auto-generated method stub
		
	}
	
}
